@@ -17,6 +17,7 @@
 
 import sys
 import os
+import glob
 import argparse
 from pathlib import Path
 from Bio import SeqIO
@@ -291,8 +292,17 @@ def calcGroupCutoff(args):
     fcatFn.checkFileExist(coreDir + '/core_orthologs/' + coreSet, '')
     annoDir = args.annoDir
     if annoDir == '':
-        annoDir = '%s/weight_dir' % coreDir
+        annoDir = '%s/fcatOutput/%s/weight_dir' % (args.outDir, args.coreSet)
+        Path(annoDir).mkdir(parents=True, exist_ok=True)
+        # annoDir = '%s/weight_dir' % coreDir
     annoDir = os.path.abspath(annoDir)
+    for annoFile in glob.glob('%s/weight_dir/*.json' % args.coreDir):
+        annoFileName = annoFile.split('/')[-1]
+        try:
+            os.symlink('%s/weight_dir/%s' % (args.coreDir, annoFileName), '%s/%s' % (annoDir, annoFileName))
+        except FileExistsError:
+            os.remove('%s/%s' % (annoDir, annoFileName))
+            os.symlink('%s/weight_dir/%s' % (args.coreDir, annoFileName), '%s/%s' % (annoDir, annoFileName))
     fcatFn.checkFileExist(annoDir, '')
     blastDir = args.blastDir
     if blastDir == '':
@@ -337,7 +347,7 @@ def calcGroupCutoff(args):
     pool.join()
 
 def main():
-    version = '0.0.35'
+    version = '0.0.37'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
